==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/ImageSignatureFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageSignatureFluent<A extends io.fabric8.openshift.api.model.ImageSignatureFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.SignatureCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.SignatureCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.SignatureCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.SignatureCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.SignatureCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.SignatureCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.SignatureCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.SignatureCondition> buildConditions();
  public io.fabric8.openshift.api.model.SignatureCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.SignatureCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.SignatureCondition buildLastCondition();
  public io.fabric8.openshift.api.model.SignatureCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.SignatureCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.SignatureCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.SignatureCondition item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.SignatureCondition item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  public java.lang.String getContent();
  public A withContent(java.lang.String content);
  public java.lang.Boolean hasContent();
  
  /**
   * Method is deprecated. use withContent instead.
   */
  @java.lang.Deprecated
  public A withNewContent(java.lang.String arg0);
  public java.lang.String getCreated();
  public A withCreated(java.lang.String created);
  public java.lang.Boolean hasCreated();
  
  /**
   * Method is deprecated. use withCreated instead.
   */
  @java.lang.Deprecated
  public A withNewCreated(java.lang.String arg0);
  public java.lang.String getImageIdentity();
  public A withImageIdentity(java.lang.String imageIdentity);
  public java.lang.Boolean hasImageIdentity();
  
  /**
   * Method is deprecated. use withImageIdentity instead.
   */
  @java.lang.Deprecated
  public A withNewImageIdentity(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildIssuedBy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SignatureIssuer getIssuedBy();
  public io.fabric8.openshift.api.model.SignatureIssuer buildIssuedBy();
  public A withIssuedBy(io.fabric8.openshift.api.model.SignatureIssuer issuedBy);
  public java.lang.Boolean hasIssuedBy();
  public A withNewIssuedBy(java.lang.String commonName,java.lang.String organization);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> withNewIssuedBy();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> withNewIssuedByLike(io.fabric8.openshift.api.model.SignatureIssuer item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> editIssuedBy();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> editOrNewIssuedBy();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> editOrNewIssuedByLike(io.fabric8.openshift.api.model.SignatureIssuer item);
  
  /**
   * This method has been deprecated, please use method buildIssuedTo instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SignatureSubject getIssuedTo();
  public io.fabric8.openshift.api.model.SignatureSubject buildIssuedTo();
  public A withIssuedTo(io.fabric8.openshift.api.model.SignatureSubject issuedTo);
  public java.lang.Boolean hasIssuedTo();
  public A withNewIssuedTo(java.lang.String commonName,java.lang.String organization,java.lang.String publicKeyID);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> withNewIssuedTo();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> withNewIssuedToLike(io.fabric8.openshift.api.model.SignatureSubject item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> editIssuedTo();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> editOrNewIssuedTo();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> editOrNewIssuedToLike(io.fabric8.openshift.api.model.SignatureSubject item);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public A addToSignedClaims(java.lang.String key,java.lang.String value);
  public A addToSignedClaims(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromSignedClaims(java.lang.String key);
  public A removeFromSignedClaims(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getSignedClaims();
  public <K,V>A withSignedClaims(java.util.Map<java.lang.String,java.lang.String> signedClaims);
  public java.lang.Boolean hasSignedClaims();
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SignatureConditionFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface IssuedByNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SignatureIssuerFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<N>>{
    public N and();
    public N endIssuedBy();
    
  }
  public interface IssuedToNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SignatureSubjectFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<N>>{
    public N and();
    public N endIssuedTo();
    
  }
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ImageSignatureFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageSignatureFluent<A extends io.fabric8.openshift.api.model.ImageSignatureFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.SignatureCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.SignatureCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.SignatureCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.SignatureCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.SignatureCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.SignatureCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.SignatureCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.SignatureCondition> buildConditions();
  public io.fabric8.openshift.api.model.SignatureCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.SignatureCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.SignatureCondition buildLastCondition();
  public io.fabric8.openshift.api.model.SignatureCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.SignatureCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.SignatureCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.SignatureCondition item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.SignatureCondition item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.SignatureConditionBuilder> predicate);
  public java.lang.String getContent();
  public A withContent(java.lang.String content);
  public java.lang.Boolean hasContent();
  
  /**
   * Method is deprecated. use withContent instead.
   */
  @java.lang.Deprecated
  public A withNewContent(java.lang.String arg0);
  public java.lang.String getCreated();
  public A withCreated(java.lang.String created);
  public java.lang.Boolean hasCreated();
  
  /**
   * Method is deprecated. use withCreated instead.
   */
  @java.lang.Deprecated
  public A withNewCreated(java.lang.String arg0);
  public java.lang.String getImageIdentity();
  public A withImageIdentity(java.lang.String imageIdentity);
  public java.lang.Boolean hasImageIdentity();
  
  /**
   * Method is deprecated. use withImageIdentity instead.
   */
  @java.lang.Deprecated
  public A withNewImageIdentity(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildIssuedBy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SignatureIssuer getIssuedBy();
  public io.fabric8.openshift.api.model.SignatureIssuer buildIssuedBy();
  public A withIssuedBy(io.fabric8.openshift.api.model.SignatureIssuer issuedBy);
  public java.lang.Boolean hasIssuedBy();
  public A withNewIssuedBy(java.lang.String commonName,java.lang.String organization);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> withNewIssuedBy();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> withNewIssuedByLike(io.fabric8.openshift.api.model.SignatureIssuer item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> editIssuedBy();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> editOrNewIssuedBy();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<A> editOrNewIssuedByLike(io.fabric8.openshift.api.model.SignatureIssuer item);
  
  /**
   * This method has been deprecated, please use method buildIssuedTo instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SignatureSubject getIssuedTo();
  public io.fabric8.openshift.api.model.SignatureSubject buildIssuedTo();
  public A withIssuedTo(io.fabric8.openshift.api.model.SignatureSubject issuedTo);
  public java.lang.Boolean hasIssuedTo();
  public A withNewIssuedTo(java.lang.String commonName,java.lang.String organization,java.lang.String publicKeyID);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> withNewIssuedTo();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> withNewIssuedToLike(io.fabric8.openshift.api.model.SignatureSubject item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> editIssuedTo();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> editOrNewIssuedTo();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<A> editOrNewIssuedToLike(io.fabric8.openshift.api.model.SignatureSubject item);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public A addToSignedClaims(java.lang.String key,java.lang.String value);
  public A addToSignedClaims(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromSignedClaims(java.lang.String key);
  public A removeFromSignedClaims(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getSignedClaims();
  public <K,V>A withSignedClaims(java.util.Map<java.lang.String,java.lang.String> signedClaims);
  public java.lang.Boolean hasSignedClaims();
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SignatureConditionFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface IssuedByNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SignatureIssuerFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedByNested<N>>{
    public N and();
    public N endIssuedBy();
    
  }
  public interface IssuedToNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SignatureSubjectFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.IssuedToNested<N>>{
    public N and();
    public N endIssuedTo();
    
  }
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.ImageSignatureFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}
